@charset "utf-8";

/*
ページ全体の基本的な設定。背景色や文字色など
*/
body {
 	background-repeat: repeat;
	background-image: url(dot.png);
	background-attachment: fixed;
	background-color:#EAEDFF;
}

/*
リンク文字列に関する設定
*/
A:LINK{
  text-decoration : underline;
  color : blue;
}

A:visited{
  color:#C62C6B;
}

}
A:HOVER{
  background-color : #FFFFFF;
}

/*
ページトップにある操作ボタンの並ぶ行の設定
*/
div.adminmenu {
	text-align: right;
	font-size: 90%;
}

/*
ページトップにある操作ボタン自体の設定
*/
span.adminmenu {
	background-color: #ddf;
	color: #000;
	border-style: solid;
	border-color: #eef #aaf #aaa #eee;
	border-width: 1px;
	padding: 2px;
}

/*
日記タイトルの設定
*/
h1 {
	display:none
	text-align: right;
	color: #EAEDFF;
	font-size: 1pt;
}

/*
カレンダーの設定
*/
div.calendar {

	color: #000;
	padding: 2px;
	margin: 0em 17% 1.8em 2em;
	font-size: small;
}

div.calendar div.year {
}

/*
1日の日記全体を囲む枠の設定
*/
div.day {
	background-color: transparent;
	border: 1px solid gray;
	text-align: left;
	text-indent-Left: 1em;
	margin-left: 5%;
	margin-right: 1%;
	padding-bottom: 0em;
	margin-bottom: 4em;
}

/*
タイトル行全体の設定
*/
h2 {
	color: #000000;
	font-size: 14pt;
	background: url(header.png) repeat;
	border-bottom: 1px sorid gray;
	padding: 0.3em 2px 0.3em 1.5em;
	text-align: left;
	margin: 0em 0em 0em 0em;
text-decoration: none;
}

/*
日付の設定
*/
h2 span.date {
font-size:20pt;
	color: #000000;
	text-decoration: none;
}

/*
タイトルの設定
*/
h2 span.title {
	
}

/*
タイトルを除いた1日の日記本文全体の設定
*/
div.body {
	text-align: left;
	background-color: transparent;
	color: #000;
	padding: 4px;
	margin: 0.5em 0.7em 0.5em 0.7em;
}

/*
サブタイトルを含むセクションの設定
*/
div.section {
	font: 11pt/150% MS P ゴシック;
	line-height: 100%;
	border: 1px solid gray;
	background-image: dot_section.png;
	background-repeat: repeat;
	padding: 0em 0em 0.7em 0em;
	margin: 0.5em 0.2em 1.2em 0.2em;
	line-break: strict;
	word-break: keep-all
	white-space: normal;
}

/*
サブタイトルの設定
*/
h3{
	color: #FFFFFF;
	background: url(header2.png) repeat;
	padding: 0.2em 0em 0.2em 2em;
	line-height: 26px;
	margin: 0em;
	font-weight: bold;
	font-size: medium;
	border-style: ridge;
	border-color: gray;
	border-width: 0px 0px 1px 0px;
}

h3 A:link {
	text-decoration: none;
}

/*
その他の見出し(必要なら)
*/
h4 {
	margin: 2em;
	font-weight: bold;
	margin-bottom: 0em;
}

P.recentitem {
	border-bottom: 1px solid gray;
	margin: 0em;
	background: url(header3.png) repeat;
	color:#FFFFFF;
	font-weight: bold;
}
 
p.MenuItem {
	margin-bottom: 1em;
font-size:9pt;
}

div.contents {
	border: 1px solid gray;
	margin-left: 30%;
	margin-right: 15%;
	margin-bottom: 1.7em;
	padding: 0em 0px 0.3em 0em;
	background-image: dot_section.png;
	background-repeat: repeat;

}

/*
イメージアンカーの設定
ただしDefaultテーマではイメージアンカーは使っていないのでコメントにしてある
指定のコツは以下の通り
  - span.sanchorはセクションアンカー、span.canchorはツッコミアンカー
  - background-imageにアンカー画像を指定
  - paddingのtop(最初)とright(2番目)に画像の縦横サイズを指定
  - colorに背景色と同じ色を指定(文字を見えなくするため)
*/

div.day span.sanchor {
	background-image: url(sanchor.png);
	background-repeat: no-repeat;
	color: #BDC7E7;
	background-color: transparent;
	background-position: 120% 120%;
	font-size: 8pt;
	text-decoration: none;
	padding: 16px 16px 0px 0px;
	vertical-align:top;
}

div.day span.sanchor a:link {
	color: transparent;
	text-decoration: none;
}


div.day span.canchor {
	background-image: url(sanchor.png);
	background-repeat: no-repeat;
	color: #BDC7E7;
	background-color: transparent;
	background-position: 100% 60%;
	font-size: 1pt;
	text-decoration: none;
	padding: 16px 16px 0px 0px;
	vertical-align:middle;
}


/*
日記の本文(段落)の設定
*/
div.section p {
	margin: 0.7em 1em 0.5em 1em;
	line-height: 150%;
	line-height: 100%;
	padding: 0em 1em 0em 1em;
}

/*
ツッコミ/フォーム/リンク元のキャプション設定
*/
div.caption {
	font-weight: bold;
	font-size: 90%;
	font-color: #000;
	margin: 0em;
	background: url(header3.png) repeat;
	padding: 0.2em 1em 0.2em 1em;
}

/*
ツッコミ欄全体の設定
*/
div.comment {
	background-color: transparent;
	color: #FFF;
	border-top: 1px solid gray;
	padding: 0em;
	margin-top: 2em;
	margin-left: 0em;
	margin-right: 0em;
	margin-bottom: 0em;
}

/*
ツッコミ省略版本文
*/
div.commentshort {
	font-size: 90%;
	padding: 0.5em 0em 0.5em 0.5em;
	COLOR: #000;
}
span.commentator {
	font-weight: bold;
}
div.commentshort p {
	margin-top: 0.2em;
	margin-bottom: 0.2em;
	line-height: 120%;
}

/*
ツッコミ本体
*/
div.commentbody {
	color: #000;
	font-size: 90%;
	margin: 1em 2em 1em 2em;

	line-height: 120%;
	border-top: 1px solid gray;
}

/*
ツッコミした人の情報
*/
div.commentator {
	COLOR: #000;
	background-color:#BDC7E7;
	border-bottom: 1px solid gray;
	line-height: 150%;
}

/*
ツッコミ本文
*/
div.commentbody p {
	margin: 0.5em;
	margin-left: 2em;
	color: #000;
	padding: 0.8em 0em 0.8em 1.2em;
}

/*
フォーム全体を囲む枠の設定
*/
div.form {
	font-weight: bold;
	background-color: transparent;
	color: #FFF;
	border-bottom:1px solid gray;

	padding: 0px;
	margin: 0em 0em 0.5em 0em;
}

/*
フォームの設定
*/
div.form form {
	font-color: white;
	margin: 1em;
	background-color:#BDC7E7;
}

div.form form.comment {
	font-size: 90%;
}

div.field {
	display: inline;
	margin-right: 2em;
}
form.comment input {
	background-color: #eef;
	color: #000;
	margin-left: 1em;
}

div.textarea {
	display: block;
	vertical-align: top;
}
form.comment textarea {
	display: block;
	background-color: #eef;
	color: #000;
	margin-left: 3em;
	width: 30em;
	height: 5em;
}

div.button {
	display: block;
	margin:0.5em 0em 0.5em 3em;
}

/*
リンク元リスト(Month/Latestモード)の設定
*/



div.referer {
	background-color: transparent;
	color: #000;
	border-top: 1px solid gray;
	padding-bottom: 0.5em;
	margin-top: 0em;
	margin-left: 0em;
	margin-right: 0em;
	margin-bottom: 0em;
}

/*
リンク元リスト(Dayモード)の設定
*/
div.refererlist {
	background-color: transparent;
	color: #000;
	border-top: 1px solid gray;
	padding-bottom: 0.5em;
	margin-top: 0em;
	margin-left: 0em;
	margin-right: 0em;
	margin-bottom: 0em;
}

/*
リンク元リスト一覧の設定
*/
div.refererlist ul {
	background-color: transparent;
	color: #000;
	border-top: 1px solid gray;
	padding: 0.5em;
	margin-top: 0em;
	margin-left: 0em;
	margin-right: 0em;
	margin-bottom: 0em;
}

/*
罫線の設定
*/
hr {
display: none;
}

/*
日々の日記のセパレータに使われる罫線の設定
*/
hr.sep {
	display: none;
}

/*
フッタの設定
*/
div.footer {
	font-size: 90%;
	text-align: right;
	margin-top: 0px;
}

/*
更新フォーム
*/
form.update {
	padding-top: 0.5em;
	border: 1px solid gray
}

form.update input, form.update textarea, form.commentstat input {
	background-color: #eef;
	color: #000;
}

form.update span.field {
	display: inline;
	margin-left: 0.5em;
	margin-right: 0.5em;
}

form.update div.field.title {
	display: block;
	margin-top: 1em;
}
form.update div.field.title input {
	margin: 0.5em;
}

form.update div.textarea {
	display: block;
	margin-top: 1em;
}
form.update textarea {
	display: block;
	margin-left: 3em;
	margin-bottom: 1em;
	width: 45em;
	height: 45em;
}

form.update span.checkbox.hidediary {
	margin-left: 1em;
}
 
textarea.body {
	width: 45em;
	height: 45em;
	display: block;
	margin-left: 3em;
	margin-bottom: 1em;
}

/*
ツッコミ状態変更フォーム
*/
div.comment form {
	margin-top: 0em;
}

/*
エラーメッセージ表示の設定
*/
p.message {
	text-align: center;
	font-size: large;
	background-color: #d00;
	color: #fff;
	padding: 8px;
}

/*
整形済みテキスト(preタグ)の設定
*/
div.section pre {
	background-color: #transparent;
	color: #000;
	margin-left: 2em;
	margin-right: 1em;
	padding: 2px 2px 8px 2px;
font-size : 12pt;
line-height : 18px;
}

/*
引用(blockquoteタグ)の設定
*/
div.section blockquote {
	border-style: solid;
	border-color: #ddf;
	border-width: 2px 2px 2px 2px;
	margin-left: 2em;
	margin-right: 2em;
	padding: 4px 4px 4px 4px;
font-size: 9pt;
}
div.section blockquote p {
	margin: 0.5em 0em 0.5em 0em;
}

/*
箇条書きの設定
*/
div.section ul, div.section ol {
	margin-left: 5em;
	margin-right: 3em;
	padding-left: 0px;
}
div.section ul ul, div.section ol ol {
	margin-left: 1.7em;
	margin-right: 1em;
	margin-bottom: 0.5em;
}

/*
項目リストの設定
*/
div.section dl {
	margin-left: 5em;
}

div.section dt {
	margin-bottom: 0.2em;
	font-weight: bold;
}

div.section dd {
	margin: 0em 3em 0.5em 1em;
}

/*
テーブルの設定
*/
div.section table {
	margin: 0.5em 1em 0.5em 5em;
	border-style: solid;
	border-width: 2px;
	border-color: #aaf;
	border-collapse: collapse;
}
div.section th, div.section td {
	padding: 5px;
	border-style: solid;
	border-width: 1px;
	border-color: #aaf;
}

/*
 いくつかのメジャーなプラグイン対応
 */

/* calendar2 */
table.calendar {
	font-size: x-small;
	line-height: 110%;
	border-style: solid;
	border-color: #aaf;
	border-width: 1px;
}

table.calendar td {
	margin: 0px;
	text-align: right;
	padding: 0px;
	margin: 0px;
}

table.calendar td.calendar-prev-month, table.calendar td.calendar-current-month, table.calendar td.calendar-next-month {
	text-align: center;
}

/* recent_list */


div.recentsubtitles {
	font-size: 90%;
	margin-top: 0px;
	margin-bottom: 1em;
	margin-left: 1em;
}

/* footnote */
div.body span.footnote {
	vertical-align: super;
	font-size: 70%;
}

div.footnote {
	font-size: 90%;
	border-style: solid;
	border-color: #ddf;
	border-width: 1px 0px 0px 0px;
	padding: 0em;
	margin-left: 6em;
}

p.footnote {
	margin: 0.5em;
	padding: 0em;
}

/* amazon plugin */
img.left {
	border-width: 1px;
	border-color: #008;
	float: left;
	margin: 0.5em;
}

img.right {
	border-width: 1px;
	border-color: #008;
	float: right;
	margin: 0.5em;
}

div.section, div.comment {
	clear: none;
}

/*
サイドバー関連
*/
div.main {
	margin-left: 18%;
}

div.sidebar {
position: absolute;
top: 80px;
left: 0px;
margin-left: 2%;

border: 1px solid gray;
	width: 18%;
	float: right;
	padding: 0px 0px 2px 0px;
	font:  11pt/150% MS ゴシック;
	margin-right:2%
}

div.sidebar p {
	line-height: 120%;
	text-align: center;
	border-style: solid;
	border-color: #aaf;
	border-width: 0px 0px 1px 0px;
	margin: 0px 0px 2px 0px;
	padding: 0px 6px 2px 0px;
}
img.photo {
	float: right;
	margin: 9px;
	border: 2px double gray;
}
a.keyword {
	text-decoration: none;
	border-bottom: 1px solid gray;
}
a.keyword:link{ color: #4271B5; background-color: transparent;}

div.img {
	float: right;
	font-size: small;
	text-align: left;
	margin: 2px 4px;
}

div.img p.caption {
	float: right;
	font-weight: bold;
	text-align: center;
	margin: 0em;
	line-height: 1.0;
}

div.img p.sentence {
	float: right;
	text-align: left;
	margin: 0em;
	padding: 2px;
}

