@charset "utf-8";
/*
Title: sakura.css
Revision: $Revision: 1.7 $
Author: しんちゃん
Access: stakei@nga.jp
License: GPL
Comment: 桜色なテーマ

	Copyright by (C) nga <http://nga.jp/>
 */

/* ChangeLog
2002-04-05 TADA Tadashi <sho@spc.gr.jp>
	* font-size: smaller -> 0.9em.

2002-04-03 nga<stakei@nga.jp>
	* add spec.
*/

body {
	background-color: #FFF5EE;
	border-color:#DB7093;
	border-style: solid;
	border-width: 1px 1px 1px 25px;
	padding: 0px;
	padding-bottom: 1px;
	margin-left: 0em;
	margin-right: 1em;
}
a:link, a:visited {
	background-color:transparent; 
	color: #B22222;
	text-decoration: none;
	border-style: none;
	border-width: 1px;
}

a:active {
	text-decoration: underline;
	border-width: 1px;
}

a:hover, a:focus {
	text-decoration: underline;
	color: #B22222;
	background-color: #FFC0CB;
	border-style: none;
	border-width: 1px;
}
/*
ページトップにある操作ボタンの並ぶ行の設定
*/
div.adminmenu {
	text-align: right;
	font-size: small;
}

/*
ページトップにある操作ボタン自体の設定
*/
span.adminmenu {
	background-color: #ddd;
	border-style: solid;
	border-color: #eee #aaa #aaa #eee;
	border-width: 1px;
	padding: 3px;
}

/*
日記タイトルの設定
*/
h1 {
	text-align: center;
}

/*
カレンダーの設定
*/
div.calendar {
	background-color: #FFF5EE;
	text-align:right;
	border-style: solid;
	border-color: #FFC0CB;
	border-width: 1px 1px 1px 25px;
	padding: 2px;
	margin-right: 1em;
	margin-bottom: 0.5em;
}

/*
1日の日記全体を囲む枠の設定
*/
div.day {
	background-color: #FFF;
	color: black;
	border-style: solid;
	border-color: #FFC0CB;
	border-width: 0px 0px 0px 25px;
	margin-left: 0;
	margin-right: 1em;
	margin-bottom: 0;
}

/*
タイトル行全体の設定
*/
h2 {
	background-color: #FFF5EE;
	color: #C71585;
	margin-top: 0.1em;
	margin-bottom: 0em;
	border-color:#FFE4E1;
	border-style: solid;
	border-width: 25px 0px 0px 25px;
	padding: 0.5em;
	margin-top: 0;
	margin-left: 0em;
	margin-right: 0;
}

div.section {
	background-color: #FFF5EE;


	margin-left: 2em;
	margin-right: 2em;
}

div.section p {
	text-indent:1em;
	margin-left: 1em;
	margin-bottom: 1em;
	line-height:1.4;
}
/*
日付の設定
*/
h2 span.date {

	margin-left: 0.5em;
}

/*
タイトルの設定
*/
h2 span.title {
	font-size: small; 
}

/*
タイトルを除いた1日の日記本文全体の設定
*/
div.body {
	background-color: #FFF5EE;
	border-color:#FFE4E1;
	border-style: solid;
	border-width: 1px 1px 1px 25px;
	padding: 2px;
	padding-bottom: 1px;
	margin-left: 0em;
	margin-right: 0;
}

/*
サブタイトルの設定
*/
h3 {
	font-size: medium;
	margin: 0em;
	padding: 0.5em;
	font-weight: bold;
}

/*
日記の本文(段落)の設定
*/
div.section p {
	margin-top: 0.5em;
	margin-bottom: 0.7em;
	line-height: 1.3;
}

/*
ツッコミ欄全体の設定
*/
div.comment {
	background-color: #FFF5EE;
	border-color:#FFE4E1;
	border-style: solid;
	border-width: 1px 1px 1px 25px;
	font-size: small;
	padding: 1em 2px 1px 3em;
	margin: 0em;
}

div.comment p {
}

/*
ツッコミ欄タイトル行の設定
*/
div.comment div.caption {
	border-style: solid;
	border-color: #aaa;
	border-width: 0px 0px 1px 0px;
}

/*
ツッコミした人の名前の設定
*/

/*
リンク元リスト(短い方)の設定
*/
div.referer {
	background-color: #FFF5EE;
	border-color:#FFE4E1;
	border-style: solid;
	border-width: 1px 1px 1px 25px;
	padding-top: 1em;
	padding-bottom: 1em;
	padding-left:3em;
	margin-top: 0;
	margin-bottom: 0;
	margin-left: 0;
	margin-right: 0;
}

/*
リンク元リスト(全体一覧)の設定
*/
div.refererlist {
	font-size: small;
	background-color: #FFF5EE;
	border-color:#FFE4E1;
	border-style: solid;
	border-width: 1px 1px 1px 25px;
	padding: 2px;
	margin-left: 0em;
	margin-bottom: 0;
}

/*
リンク元リストタイトルの設定
*/
div.refererlist div.caption {
	border-style: solid;
	border-color: #aaa;
	border-width: 0px 0px 1px 0px;
}

/*
リンク元リスト一覧の設定
*/
div.refererlist ul {
	margin-top: 0em;
}

/*
罫線の設定
*/
hr {
	border-style: solid;
	border-width: 2px 0px 0px 0px;
	border-color: #ddd;
}

/*
日々の日記のセパレータに使われる罫線の設定
*/
hr.sep {
	display: none;
}

/*
フッタの設定
*/
div.footer {
	font-size: small;
	text-align: right;
	margin-top: 0px;
}

/*
フォーム全体を囲む枠の設定
*/
div.form {
	font-size: small;
	background-color: #FFF5EE;
	border-color:#FFE4E1;
	border-style: solid;
	border-width: 1px 1px 1px 25px;
	padding: 2px;
	margin-left: 0em;
	margin-bottom: 0;
}

/*
入力フィールドの設定
*/
input.field {
	background-color: white;
}

/*
複数行入力フィールドの設定
*/
textarea {
	background-color: white;
	margin-left: 1em;
	width: 30em;
}

/*
エラーメッセージ表示の設定
*/
p.message {
	text-align: center;
	font-size: large;
	background-color: red;
	color: white;
	padding: 8px;
}

/*
整形済みテキスト(preタグ)の設定
*/
pre {
	background-color: #FFFAF0;
	color: #000;
	border-color:#DB7093;
	border-style: solid;
	border-width: 1px 1px 1px 5px;
	margin-left: 2em;
	margin-right: 1em;
	padding: 8px 8px 8px 8px;
}

/*
項目リストの設定
*/
div.body dl {
	margin-left: 2em;
}

div.body dt {
	margin-bottom: 0.2em;
	font-weight: bold;
}

div.body dd {
	margin-left: 1em;
	margin-bottom: 0.5em;
}

img {
	border-style: none;
}

/*
Calendar2の設定
*/
table.calendar {
	text-align: center;
	color: #000000;
	background-color: #FFF5EE;
	border-style: solid;
	border-color: #DB7093;
	border-width: 1px;
	margin-bottom: 1em;
}

td.calendar-current-month {
	font-size: xx-small;
	text-align: center;
}

td.calendar-next-month {
	font-size: xx-small;
	text-align: right;
}

td.calendar-prev-month {
	font-size: xx-small;
	text-align: left;
}

td.calendar-sunday {
	color: red;
	background-color: #fbb;
	font-size: xx-small;
	text-align: center;
}

td.calendar-saturday {
	color: blue;
	background-color: #bbf;
	font-size: xx-small;
	text-align: center;
}

td.calendar-weekday {
	color: #000000;
	background-color: #ddd;
	font-size: xx-small;
	text-align: center;
}

td.calendar-day {
	font-size: xx-small;
	text-align: right;
}

/*
footnoteの設定
*/

span.footnote {
	font-size: x-small;
	vertical-align:  super;
}

div.footnote {
	background-color: #FFE4E1;
	padding: 5px;
	padding-bottom: 1px;
	margin-top:1em;
	margin-left: 36px;
	margin-right: 24px;
}
p.footnote {
	font-size: 90%;
	padding-bottom: 5px;
}

/*
ツッコミ省略版本文
*/
div.commentshort {
        margin-left: 0.5em;
}

span.commentator {
}

div.commentshort p {
        margin-top: 0.2em;
        margin-bottom: 0.2em;
        line-height: 1.2em;
}

/*
ツッコミ本体
*/
div.commentbody {
        margin: 0.5em;
        line-height: 1.2em;
}

/*
ツッコミした人の情報
*/
div.commentator {
        border-style: solid;
        border-color: #aaa;
        border-width: 0px 0px 1px 0px;
        line-height: 1.5em;
	display: inline;
}

/*
ツッコミ本文
*/
div.commentbody p {
        margin: 0.5em;
}

/*
フォームの設定
*/
div.form form {
        margin: 0em;
}

div.form div.caption {
        border-style: solid;
        border-color: #aaa;
        border-width: 0px 0px 1px 0px;
        margin: 0.5em;
}

div.form form.comment {
}

div.field {
        display: inline;
        margin-right: 2em;
}

form.comment input {
        background-color: white;
        margin-left: 1em;
}

div.textarea {
        display: block;
        vertical-align: top;
}

form.comment textarea {
        display: block;
        background-color: white;
        width: 30em;
        height: 5em;
}

div.button {
        display: block;
}

/*
更新フォーム
*/
form.update {
        padding-top: 0.5em;
        padding-bottom: 0.5em;
}

form.update input, form.update textarea, form.commentstat input {
        background-color: white;
}

form.update span.field {
        display: inline;
        margin-left: 0em;
        margin-right: 0.5em;
}

form.update div.field.title {
        display: block;
        margin-top: 1em;
}

form.update div.field.title input {
        margin-left: 0.5em;
}

form.update div.textarea {
        display: block;
        margin-top: 1em;
}

form.update textarea {
        display: block;
        margin-bottom: 1em;
        width: 35em;
        height: 15em;
}

form.update span.checkbox.hidediary {
        margin-left: 1em;
}

/*
ツッコミ状態変更フォーム
*/
div.comment form {
        margin-top: 0em;
}
