@charset "utf-8";
/*
Title: himawari
Revision: $Revision: 1.3 $
Author: naoko
Access: naoko@undefine.to
License: GPL
Comment: ひまわりのテーマ。

validated by W3C.
サイドバー対応。
もしかしたら関連するかもしれないページ対応。
*/

/*
ページ全体の基本的な設定。背景色や文字色など
*/
body {
	background-color: #fff;
	color: #000;
	background-image: url(himawari_bg.jpg);
	background-position: right top;
	background-repeat: no-repeat;
	margin-top:0;
	margin-right:0;
}

/*
calender3プラグインを使う場合は、こっちを使うといいかも
body {
	background-color: #fff;
	color: #000;
	background-image: url(himawari_bg.jpg);
	background-position-y: 1em;
	background-position-x: right;
	background-repeat: no-repeat;
	margin-right:0;
}
*/

/*
リンク文字列に関する設定
*/
a:link {
	text-decoration: none;
	background-color: transparent;
	color:#FF621E;
}

a:visited {
	background-color: transparent;
	text-decoration: none;
	color: #FF621E;
}

a:hover {
	text-decoration: underline;
}

/*
ページトップにある操作ボタンの並ぶ行の設定
*/
div.adminmenu {
	background-color: #FEFFCA;
	color: #000;
	text-align: right;
	font-size: 90%;
	padding: 2px;
	margin-top:0;
}

/*
ページトップにある操作ボタン自体の設定
*/
span.adminmenu {
	background-color: transparent;
	color: #000;
	border-color:#FF621E;
	border-width:0 0 0 1px;
	border-style:solid;
	padding-left:2px;
}

/*
日記タイトルの設定
*/
h1 {
	background-color: transparent;
	color: #FF621E;
	height: 80px;
	line-height: 80px;
	text-align: right;
	margin-right:4px;
}

/*
カレンダーの設定
*/
div.calendar {
	background-color: transparent;
	text-align: right;
	letter-spacing: 0.1em;
	color: #222;
	padding: 2px;
	line-height: 110%;
	font-size: 90%;
	margin-right: 1em;
}

div.calendar div.year {
}

/*
1日の日記全体を囲む枠の設定
*/
div.day {
	background-color: #fff;
	color: #000;
	padding-bottom: 0.5em;
	margin:0 1em 1em 0;
}

/*
タイトル行全体の設定
*/
h2 {
	background-color: #FFFFE1;
	color: #000;
	margin-top:0;
	margin-bottom:0;
	border-top: solid 1px #FF621E;
	border-right: solid 1px #FF621E;
	border-left: solid 1px #FF621E;
	border-bottom: dashed 1px #FF621E;
	padding:2px 2px 2px 10px;
}

/*
日付の設定
*/
h2 span.date {
	font-size: medium;
}

/*
タイトルの設定
*/
h2 span.title {
	background-color: transparent;
	color: #FF6420;
}

/*
タイトルを除いた1日の日記本文全体の設定
*/
div.body {
	background-color: #fff;
	color: #000;
	margin:0;
	padding-left:1em;
	border-right: solid 1px #FF621E;
	border-left: solid 1px #FF621E;
}

/*
サブタイトルを含むセクションの設定
*/
div.section {
margin:0;
padding:1em;
}

/*
サブタイトルの設定
*/
h3 {
	font-size: medium;
	margin-top: 0;
	padding-left:1em;
	font-weight: bold;
}

/*
その他の見出し(必要なら)
*/
h4 {
	margin: 2em;
	font-weight: bold;
	margin-bottom: 0em;
}

/*
イメージアンカーの設定
ただしDefaultテーマではイメージアンカーは使っていないのでコメントにしてある
指定のコツは以下の通り
  - span.sanchorはセクションアンカー、span.canchorはツッコミアンカー
  - background-imageにアンカー画像を指定
  - paddingのtop(最初)とright(2番目)に画像の縦横サイズを指定
  - colorに背景色と同じ色を指定(文字を見えなくするため)
*/

div.day span.sanchor {
	background-image: url(himawari_anchor.gif);
	background-position: bottom right;
	background-repeat: no-repeat;
	padding: 26px 21px 0px 0px;
	color: #fff;
	background-color: transparent;
	font-size: 1px;
}

div.day span.canchor {
	background-image: url(himawari_canchor.gif);
	background-position: bottom right;
	background-repeat: no-repeat;
	padding: 14px 17px 0px 0px;
	color: #fff;
	background-color: transparent;
	font-size: 1px;
}


/*
日記の本文(段落)の設定
*/
div.section p {
	margin: 0 1em 0 2em;
	line-height: 150%;
}

/*
ツッコミ/フォーム/リンク元のキャプション設定
*/
div.caption {
	background-color: transparent;
	font-size: 90%;
	margin-top: 0;
	padding-left:6px;
}

/*
ツッコミ欄全体の設定
*/
div.comment {
	background-color: #fff;
	color: #000;
	padding:4px;
	margin-top: 0;
	border-top: dashed 1px #FF621E;
	border-right: solid 1px #FF621E;
	border-left: solid 1px #FF621E;
	border-bottom: dashed 1px #FF621E;
}

/*
ツッコミ省略版本文
*/
div.commentshort {
	font-size: 90%;
	padding:4px;
}
span.commentator {
	font-weight: bold;

}
div.commentshort p {
	margin-top: 0.2em;
	margin-bottom: 0.2em;
	line-height: 120%;
}

/*
ツッコミ本体
*/
div.commentbody {
	font-size: 90%;
	margin: 0.5em;
	line-height: 120%;
}

/*
ツッコミした人の情報
*/
div.commentator {
	border-style: solid;
	border-color: #FCDCA7;
	border-width: 0px 0px 1px 0px;
	line-height: 150%;
}

/*
ツッコミ本文
*/
div.commentbody p {
	margin: 0.5em;
	margin-left: 2em;
}

/*
フォーム全体を囲む枠の設定
*/
div.form {
	background-color: #fff;
	color: #000;
	padding: 4px;
	padding-left:2em;
	margin: 0;
	border-right: solid 1px #FF621E;
	border-left: solid 1px #FF621E;
	border-bottom: dashed 1px #FF621E;
}

/*
フォームの設定
*/
div.form form {
	margin: 0em 0em 0em 2em;
}

div.form form.comment {
	font-size: 90%;
}

div.field {
	display: inline;
	margin-right: 2em;
}
form.comment input {
	background-color: #ffe;
	color: #000;
	margin-left: 1em;
}

div.textarea {
	display: block;
	vertical-align: top;
}
form.comment textarea {
	display: block;
	background-color: #ffe;
	color: #000;
	margin-left: 3em;
	width: 30em;
	height: 5em;
}

div.button {
	display: block;
	margin-left: 3em;
}

/*
リンク元リスト(Month/Latestモード)の設定
*/
div.referer {
	text-align: right;
	font-size: 90%;
	background-color: #FFFFE1;
	color: #000000;
	padding: 10px;
	margin: 0;
	border-right: solid 1px #FF621E;
	border-left: solid 1px #FF621E;
	border-bottom: solid 1px #FF621E;
}

/*
リンク元リスト(Dayモード)の設定
*/
div.refererlist {
	background-color: #FFFFE1;
	color: #000;
	padding: 2px;
	padding-bottom: 1px;
	margin: 0;
	border-right: solid 1px #FF621E;
	border-left: solid 1px #FF621E;
	border-bottom: solid 1px #FF621E;
}

/*
リンク元リスト一覧の設定
*/
div.refererlist ul {
	font-size: 90%;
	margin: 0.5em 1em 0.5em 3em;
	line-height: 120%;
}

/*
罫線の設定
*/
hr {
	border-style: solid;
	border-width: 2px 0px 0px 0px;
	border-color: #FF6420;
}

/*
日々の日記のセパレータに使われる罫線の設定
*/
hr.sep {
	display: none;
}

/*
フッタの設定
*/
div.footer {
	font-size: 80%;
	text-align: right;
	margin-top: 0px;
}

/*
更新フォーム
*/

form.update {
	padding-top: 0.5em;
	padding-bottom: 0.5em;
}
form.update input, form.update textarea, form.commentstat input {
	background-color: #FFFFE1;
	color: #000;
}

form.update span.field {
	display: inline;
	margin-left: 0em;
	margin-right: 0.5em;
}

form.update div.field.title {
	display: block;
	margin-top: 1em;
}
form.update div.field.title input {
	margin-left: 0.5em;
}

form.update div.textarea {
	display: block;
	margin-top: 1em;
}
form.update textarea {
	display: block;
	margin-left: 3em;
	margin-bottom: 1em;
	width: 35em;
	height: 15em;
}

form.update span.checkbox.hidediary {
	margin-left: 1em;
}

/*
ツッコミ状態変更フォーム
*/
div.comment form {
	margin-top: 0em;	
}

/*
エラーメッセージ表示の設定
*/
p.message {
	text-align: center;
	font-size: large;
	background-color: #d00;
	color: #fff;
	padding: 8px;
}

/*
整形済みテキスト(preタグ)の設定
*/
div.section pre {
	background-color: #FFFFE1;
	color: #000;
	margin-left: 3em;
	margin-right: 1em;
	padding: 8px 8px 8px 8px;
	border-width:1px;
	border-style:solid;
	border-color:#FF6420;
}

/*
引用(blockquoteタグ)の設定
*/
div.section blockquote {
	background-color: #FFFFE1;
	color: #000;
	margin-left: 3em;
	margin-right: 1em;
	padding: 8px 8px 8px 8px;
	border-width:1px;
	border-style:solid;
	border-color:#FF6420;
}
div.section blockquote p {
	margin: 0.5em 0em 0.5em 0em;
}

/*
箇条書きの設定
*/
div.section ul, div.section ol {
	margin-left: 5em;
	margin-right: 3em;
	padding-left: 0px;
	line-height: 120%;
}
div.section ul ul, div.section ol ol {
	margin-left: 1.7em;
	margin-right: 1em;
	margin-bottom: 0.5em;
}

li{
margin-bottom:0.2em;
}

/*
項目リストの設定
*/
div.section dl {
	margin-left: 5em;
}

div.section dt {
	margin-bottom: 0.2em;
	font-weight: bold;
}

div.section dd {
	margin: 0em 3em 0.5em 1em;
}

/*
テーブルの設定
*/
div.section table {
	margin: 0.5em 1em 0.5em 5em;
	border-style: solid;
	border-width: 2px;
	border-color: #aaf;
	border-collapse: collapse;
}
div.section th, div.section td {
	padding: 5px;
	border-style: solid;
	border-width: 1px;
	border-color: #aaf;
}

/*
 いくつかのメジャーなプラグイン対応
 */

/* calendar2 */
table.calendar {
	background-color: #fff;
	color:#222;
	font-size: 80%;
	line-height: 110%;
	border-style: solid;
	border-color: #FF6420;
	border-width: 1px;
	margin-left: 1em;
}

table.calendar td {
	margin: 0px;
	text-align: center;
	padding: 0 3px 0 3px;
}

table.calendar td.calendar-prev-month, table.calendar td.calendar-current-month, table.calendar td.calendar-next-month,table.calendar td.calendar-day {
	text-align: center;
	background-color: #FFFFE0;
	color:#222;
	
}

td.calendar-sunday {
	color: red;
	background-color: #fbb;
}

td.calendar-saturday {
	background-color: #bbf;
	color: blue;
}

td.calendar-weekday {
	background-color: #C0C0C0;
	color: #222;
}

/* calendar3 */

div.calendar3{
	font-size: 90%;
	line-height: 120%;
	padding: 2px;
	text-align: right;
}

.calendar-popup {
	background-color: #FFFFE0;
	color:#222;
	display: none;
	position: absolute;
	padding: 4px;
	text-align: left;
	border-color:#FF6420;
	border-width:1px;
	border-style:solid;
}

.calendar-day a{
	font-weight: normal;
	background-color:#FFFFE0;
}

.calendar-sunday {
	color: #f00;
	background-color: transparent;
}

.calendar-saturday {
	color: #00f;
	background-color: transparent;
}

.calendar-weekday {
	color: #222;
	background-color: transparent;
}
.calendar-todo {
	border-style: solid;
	border-color: #1E90FF;
	border-width: 1px;
}

/* recent_list */
p.recentitem {
	font-size: 90%;
	margin-top: 0px;
	margin-bottom: 0px;
}

div.recentsubtitles {
	font-size: 90%;
	margin-top: 0px;
	margin-bottom: 1em;
	margin-left: 1em;
}

/* footnote */
div.body span.footnote {
	vertical-align: super;
	font-size: 70%;
}

div.footnote {
	font-size: 90%;
	border-style: solid;
	border-color: #FCDCA7;
	border-width: 1px 0px 0px 0px;
	padding: 0em;
	margin-left: 6em;
}

p.footnote {
	margin: 0em;
	padding: 0.5em;
}

/* amazon plugin */
img.left {
	border-width: 1px;
	border-color: #F8C868;
	float: left;
	margin: 0.5em;
}

img.right {
	border-width: 1px;
	border-color: #F8C868;
	float: right;
	margin: 0.5em;
}

div.section, div.comment {
	clear: both;
}

/* もしかしたら関連するかもしれないページ */
div.body-enter{
	font-size:90%;
	padding:0.5em;
	text-align:right;
}

/*
サイドバー関連
*/
div.main {
	margin-left: 25%;
}

div.sidebar {
	background-color: #FFFFE1;
	color: #000;
	position: absolute;
	top: 0px;
	left: 0px;
	width: 24%;
	padding: 2px 2px 100% 2px;
	border-style: solid;
	border-color: #F8C868;
	border-width: 0px 2px 2px 0px;
	padding-top: 0.5em;
}

div.sidebar p {
	line-height: 120%;
	text-align: center;
	border-style: solid;
	border-color: #F8C868;
	border-width: 0px 0px 1px 0px;
	margin: 2px 4px 2px 4px;
}
