@charset "utf-8";
/*
Title: Friday
Revision: $Revision: 1.7 $
Author: zoe
Access: http://www.kasumi.sakura.ne.jp/~zoe/
License: GPL

        Copyright (C) ZOE http://kasumi.sakura.ne.jp/~zoe
        Modified by Nana 
	validated by W3C
*/
/* ChangeLog
2002-09-16 NT <nt@24i.net>
        * convert for 1.5 series.

2002-04-05 TADA Tadashi <sho@spc.gr.jp>
	* add spec.
*/

body {
	background-color: #000000;
	color: #ffffff;
}

a:link {
        text-decoration: none;
	color: #ff8;
}
a:visited {
        text-decoration: none;
        color: #ff8;
}
a:hover,a:active {
	text-decoration: none;
        color: #c90;
}

div.adminmenu {
	text-align: right;
	font-size: small;
}

p.message {
	text-align: center;
	font-size: medium;
	background-color: #000000;
	color: white;
	padding: 8px;
}

span.adminmenu {
	background-color: transparent;
	padding: 3px;
}

h1 {
	text-align: center;
}

div.calendar {
	background-color: transparent;
	text-align: right;
	padding: 2px;
	margin-bottom: 0.5em;
}

div.day {
	margin: 3em auto 3em auto;
	text-align: right;
	clear: both;
	width: 480px;
	border-style: double solid double solid;
	border-color: #fcc;
	border-width: 6px 1px 6px 1px;
}
h2 {
	text-align: right;
	margin: 0.1em 0em 0em auto;
	font-weight: normal;
}

h2 span.date {
	font-size: medium;
	position: relative;
	top: -10px;
	left: -20px;
	text-align: left;
	background-color: #000;
	margin-bottom: 0em;
	margin-left: auto;
	margin-right: 0px;
	padding-bottom: 0em;
	border-style: double solid double solid;
	border-color: #fff #aaa #aaa #fff;
	border-width: 4px 1px 4px 1px;
}

h2 span.title {
	font-size: medium;
}

div.body {
	margin: 0px auto 0px auto;
	padding-top: 0.5em;
	padding-bottom: 0.5em;
	text-align: left;
	width: 480px;
	color: #fcc;
}

p.body {
	margin-top: 0em;
	margin-bottom: 0em;
	line-height: 1.2em;
	padding-left: 1em;
	padding-top:0em;
}
div.section p {
	margin-top: 0.5em;
	margin-bottom: 0.7em;
	line-height: 1.3em;
}
div.body p {
	margin-left: 12px;
	margin-right: 12px;
	line-height: 1.2em;
	border-style: none;
	border-color: #ccc;
	border-width: 1px 0px 0px 0px;
}

h3 {
	margin: 0.2em 2px 0em 2px;
	font-weight: bold;
	font-size: medium;
	clear: both;
}
span.anchor {
	margin: 0em 12px;
	font-weight: bold;
	font-size: 24pt;
	float: left;
}

pre {
	background-color: black;
	color: #ff8000;
	margin-left: 2em;
	margin-right: 1em;
	padding: 8px 8px 8px 8px;
}

div.comment {
	font-size: x-small;
	clear: both;
	width: 480px;
	text-align: right;
	padding-bottom: 1px;
	margin: auto 12px 12px 0px;
	border-style: double;
	border-color: #fcc;
	border-width: 3px 0px 0px 0px;
}

div.comment div.caption {
	text-align: right;
	background-color: #000;
	position: relative;
	top: -10px;
	left: -20px;
	color: #cff;
	display: inline;
	font-size: medium;
	margin-bottom: 0px;
	padding-bottom: 0px;
	border-style: double solid double solid;
	border-color: #fff #aaa #aaa #fff;
	border-width: 4px 1px 4px 1px;
}


div.comment p {
	font-size: x-small;
	text-align: left;
	color: #cff;
	padding: 0px 0px 0px 0px;
	margin: 0px 12px 2px 24px;
	line-height: 1.2em;
}
div.refererlist div.caption {
	color: #8f8;
	background-color: #000;
	text-align: right;
	display: inline;
	position: relative;
	top: -10px;
	left: -20px;
	border-style: double solid double solid;
	border-color: #fff #aaa #aaa #fff;
	border-width: 4px 1px 4px 1px;
}

div.referer {
	display: inline;
	text-align: right;
	color: #8f8;
	position: relative;
	top: 10px;
	left: -20px;
	clear: both;
	font-size: x-small;
	background-color: #000;
	padding: 2px;
	border-style: double solid double solid;
	border-color: #fff #ccc #ccc #fff;
	border-width: 4px 1px 4px 1px;
}

div.refererlist {
	font-size: x-small;
	text-align: right;
	padding-bottom: 1px;
	margin-top: 0.2em;
	border-style: double;
	border-color: #fcc;
	border-width: 3px 0px 0px 0px;
}

div.refererlist ul {
	margin-top: 0em;
	text-align: left;
	list-style-type: upper-roman;
}

hr {
	border-style: solid;
	border-width: 2px 0px 0px 0px;
	border-color: #ddd;
}

hr.sep {
	display: none;
}


div.footer {
	font-size: x-small;
	text-align: right;
	margin-top: 0px;
	clear: both;
}

div.form {
	background-color: transparent;
	font-size: small;
	padding: 0.5em 1em 0.5em 1em;
	margin-bottom: 0.5em;
}
form {
	background-color: transparent;
	text-align: left;
	padding: 0.5em 1em 0.5em 1em;
	margin-bottom: 0.5em;
}


input.field {
	background-color: transparent;
	font-size: small;
	color: #fff;
	border-color: #f80;
	border-style: solid;
	border-width: 1px;
}

input {
	background-color: transparent;
	font-size: small;
	color: #fff;
	border-color: #f80;
	border-style: double solid double solid;
	border-width: 4px 1px 4px 1px;
	clear: both;
}

textarea {
	background-color: transparent;
	font-size: small;
	color: #fff;
	border-color: #f80;
	border-style: double solid double solid;
	border-width: 4px 1px 4px 1px;
}

div.body dl {
	margin-left: 2em;
}

div.body dt {
	margin-bottom: 0.2em;
	font-weight: bold;
}

div.body dd {
	margin-left: 1em;
	margin-bottom: 0.5em;
}

/*
ツッコミ省略版本文
*/
div.commentshort {
        font-size: 90%;
        margin-left: 0.5em;
}

span.commentator {
        font-weight: bold;
}

div.commentshort p {
        margin-top: 0.2em;
        margin-bottom: 0.2em;
        line-height: 1.2em;
}

/*
ツッコミ本体
*/
div.commentbody {
        font-size: 90%;
        margin: 0.5em;
        line-height: 1.2em;
}

/*
ツッコミした人の情報
*/
div.commentator {
        border-style: solid;
        border-color: #fff#aaa#aaa#fff;
        border-width: 0px 0px 1px 0px;
        line-height: 1.5em;
}

/*
ツッコミ本文
*/
div.commentbody p {
        margin: 0.5em;
        margin-left: 2em;
}

/*
フォームの設定
*/
div.form form {
        margin: 0em 0em 0em 2em;
}

div.form div.caption {
        font-size: 90%;
        border-style: solid;
        border-color: #fff#aaa#aaa#fff;
        border-width: 0px 0px 1px 0px;
        margin: 0.5em;
}

div.form form.comment {
        font-size: 90%;
}

div.field {
        display: inline;
}

form.comment input {
        background-color: transparent;
        color: #fff;
        margin-left: 1em;
}

div.textarea {
        display: block;
        vertical-align: top;
	margin: 0.5em 0em 0.5em 0em;
}

form.comment textarea {
        display: block;
        background-color: transparent;
        color: #fff;
        margin-left: 3em;
        width: 30em;
        height: 5em;
}

div.button {
        display: block;
        margin-left: 3em;
}

/*
更新フォーム
*/
form.update {
        padding-top: 0.5em;
        padding-bottom: 0.5em;
}

form.update input, form.update textarea, form.commentstat input {
        background-color: transparent;
        color: #fff;
}

form.update span.field {
        display: inline;
        margin-left: 0em;
        margin-right: 0.5em;
}

form.update div.field.title {
        display: block;
        margin-top: 1em;
}

form.update div.field.title input {
        margin-left: 0.5em;
}

form.update div.textarea {
        display: block;
        margin-top: 1em;
}

form.update textarea {
        display: block;
        margin-left: 3em;
        margin-bottom: 1em;
        width: 30em;
        height: 15em;
}

form.update span.checkbox.hidediary {
        margin-left: 1em;
}

/*
ツッコミ状態変更フォーム
*/
div.comment form {
        margin-top: 0em;
}
